package javax.swing.plaf.nimbus;

import javax.swing.JSlider;
import java.awt.Color;
import javax.swing.JComponent;
import java.awt.geom.NoninvertibleTransformException;
import java.awt.image.BufferedImage;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.Graphics;
import javax.swing.plaf.synth.SynthContext;
import javax.swing.Painter;
import javax.swing.plaf.synth.SynthPainter;

class SynthPainterImpl extends SynthPainter
{
    private NimbusStyle style;
    
    SynthPainterImpl(NimbusStyle style) {
        this.style = style;
    }
    
    private void paint(Painter painter, SynthContext synthContext, Graphics graphics, int n, int n2, int width, int height, AffineTransform affineTransform) {
        if (painter != null) {
            if ((graphics instanceof Graphics2D)) {
                Graphics2D graphics2D = (Graphics2D)graphics;
                if (affineTransform != null) {
                    graphics2D.transform(affineTransform);
                }
                graphics2D.translate(n, n2);
                painter.paint(graphics2D, synthContext.getComponent(), width, height);
                graphics2D.translate(-n, -n2);
                if (affineTransform != null) {
                    try {
                        graphics2D.transform(affineTransform.createInverse());
                    }
                    catch (NoninvertibleTransformException ex) {
                        ex.printStackTrace();
                    }
                }
            }
            else {
                BufferedImage bufferedImage = new BufferedImage(width, height, 2);
                Graphics2D graphics2 = bufferedImage.createGraphics();
                if (affineTransform != null) {
                    graphics2.transform(affineTransform);
                }
                painter.paint(graphics2, synthContext.getComponent(), width, height);
                graphics2.dispose();
                graphics.drawImage(bufferedImage, n, n2, null);
            }
        }
    }
    
    private void paintBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, AffineTransform affineTransform) {
        JComponent component = synthContext.getComponent();
        Color color = (component != null) ? component.getBackground() : null;
        if (color == null || color.getAlpha() > 0) {
            Painter<Object> backgroundPainter = this.style.getBackgroundPainter(synthContext);
            if (backgroundPainter != null) {
                this.paint(backgroundPainter, synthContext, graphics, n, n2, n3, n4, affineTransform);
            }
        }
    }
    
    private void paintForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, AffineTransform affineTransform) {
        Painter<Object> foregroundPainter = this.style.getForegroundPainter(synthContext);
        if (foregroundPainter != null) {
            this.paint(foregroundPainter, synthContext, graphics, n, n2, n3, n4, affineTransform);
        }
    }
    
    private void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, AffineTransform affineTransform) {
        Painter<Object> borderPainter = this.style.getBorderPainter(synthContext);
        if (borderPainter != null) {
            this.paint(borderPainter, synthContext, graphics, n, n2, n3, n4, affineTransform);
        }
    }
    
    private void paintBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        int leftToRight = synthContext.getComponent().getComponentOrientation().isLeftToRight();
        if ((synthContext.getComponent() instanceof JSlider)) {
            leftToRight = true;
        }
        if (n5 == 1 && leftToRight) {
            AffineTransform o3 = new AffineTransform();
            o3.scale(-1.0, 1.0);
            o3.rotate(Math.toRadians(90.0));
            this.paintBackground(synthContext, graphics, n2, n, n4, n3, o3);
        }
        else if (n5 == 1) {
            AffineTransform o2 = new AffineTransform();
            o2.rotate(Math.toRadians(90.0));
            o2.translate(0.0, (double)(-(n + n3)));
            this.paintBackground(synthContext, graphics, n2, n, n4, n3, o2);
        }
        else if (n5 == 0 && leftToRight) {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform o = new AffineTransform();
            o.translate((double)n, (double)n2);
            o.scale(-1.0, 1.0);
            o.translate((double)(-n3), 0.0);
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, o);
        }
    }
    
    private void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        int leftToRight = synthContext.getComponent().getComponentOrientation().isLeftToRight();
        if (n5 == 1 && leftToRight) {
            AffineTransform affineTransform2 = new AffineTransform();
            affineTransform2.scale(-1.0, 1.0);
            affineTransform2.rotate(Math.toRadians(90.0));
            this.paintBorder(synthContext, graphics, n2, n, n4, n3, affineTransform2);
        }
        else if (n5 == 1) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.rotate(Math.toRadians(90.0));
            affineTransform.translate(0.0, (double)(-(n + n3)));
            this.paintBorder(synthContext, graphics, n2, 0, n4, n3, affineTransform);
        }
        else if (n5 == 0 && leftToRight) {
            this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
        }
    }
    
    private void paintForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        int leftToRight = synthContext.getComponent().getComponentOrientation().isLeftToRight();
        if (n5 == 1 && leftToRight) {
            AffineTransform affineTransform2 = new AffineTransform();
            affineTransform2.scale(-1.0, 1.0);
            affineTransform2.rotate(Math.toRadians(90.0));
            this.paintForeground(synthContext, graphics, n2, n, n4, n3, affineTransform2);
        }
        else if (n5 == 1) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.rotate(Math.toRadians(90.0));
            affineTransform.translate(0.0, (double)(-(n + n3)));
            this.paintForeground(synthContext, graphics, n2, 0, n4, n3, affineTransform);
        }
        else if (n5 == 0 && leftToRight) {
            this.paintForeground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            this.paintForeground(synthContext, graphics, n, n2, n3, n4, null);
        }
    }
    
    @Override
    public void paintArrowButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintArrowButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintArrowButtonForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        String name = synthContext.getComponent().getName();
        int leftToRight = synthContext.getComponent().getComponentOrientation().isLeftToRight();
        if ("Spinner.nextButton".equals(name) || "Spinner.previousButton".equals(name)) {
            if (!(leftToRight == 0)) {
                this.paintForeground(synthContext, graphics, n, n2, n3, n4, null);
            }
            else {
                AffineTransform affineTransform6 = new AffineTransform();
                affineTransform6.translate((double)n3, 0.0);
                affineTransform6.scale(-1.0, 1.0);
                this.paintForeground(synthContext, graphics, n, n2, n3, n4, affineTransform6);
            }
        }
        else if (n5 == 7) {
            this.paintForeground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else if (n5 == 1) {
            if (!(leftToRight == 0)) {
                AffineTransform affineTransform5 = new AffineTransform();
                affineTransform5.scale(-1.0, 1.0);
                affineTransform5.rotate(Math.toRadians(90.0));
                this.paintForeground(synthContext, graphics, n2, 0, n4, n3, affineTransform5);
            }
            else {
                AffineTransform affineTransform4 = new AffineTransform();
                affineTransform4.rotate(Math.toRadians(90.0));
                affineTransform4.translate(0.0, (double)(-(n + n3)));
                this.paintForeground(synthContext, graphics, n2, 0, n4, n3, affineTransform4);
            }
        }
        else if (n5 == 3) {
            AffineTransform affineTransform3 = new AffineTransform();
            affineTransform3.translate((double)n3, 0.0);
            affineTransform3.scale(-1.0, 1.0);
            this.paintForeground(synthContext, graphics, n, n2, n3, n4, affineTransform3);
        }
        else if (n5 == 5) {
            if (!(leftToRight == 0)) {
                AffineTransform affineTransform2 = new AffineTransform();
                affineTransform2.rotate(Math.toRadians(-90.0));
                affineTransform2.translate((double)(-n4), 0.0);
                this.paintForeground(synthContext, graphics, n2, n, n4, n3, affineTransform2);
            }
            else {
                AffineTransform affineTransform = new AffineTransform();
                affineTransform.scale(-1.0, 1.0);
                affineTransform.rotate(Math.toRadians(-90.0));
                affineTransform.translate((double)(-(n4 + n2)), (double)(-(n3 + n)));
                this.paintForeground(synthContext, graphics, n2, n, n4, n3, affineTransform);
            }
        }
    }
    
    @Override
    public void paintButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintCheckBoxMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintCheckBoxMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintCheckBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintCheckBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintColorChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintColorChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintComboBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintComboBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintDesktopIconBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintDesktopIconBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintDesktopPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintDesktopPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintEditorPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintEditorPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintFileChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintFileChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintFormattedTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintFormattedTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBorder(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintInternalFrameTitlePaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintInternalFrameTitlePaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintInternalFrameBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintInternalFrameBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintLabelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintLabelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintListBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintListBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintOptionPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintOptionPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPanelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPanelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPasswordFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPasswordFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPopupMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintPopupMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintProgressBarForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintForeground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintRadioButtonMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintRadioButtonMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintRadioButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintRadioButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintRootPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintRootPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollBarThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollBarThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintScrollPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintScrollPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSeparatorForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintForeground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSliderThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        if (synthContext.getComponent().getClientProperty("Slider.paintThumbArrowShape") == Boolean.TRUE) {
            if (n5 == 0) {
                n5 = 1;
            }
            else {
                n5 = 0;
            }
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        else {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
    }
    
    @Override
    public void paintSliderThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintSpinnerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSpinnerBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        if (n5 == 1) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.scale(-1.0, 1.0);
            affineTransform.rotate(Math.toRadians(90.0));
            this.paintBackground(synthContext, graphics, n2, n, n4, n3, affineTransform);
        }
        else {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
    }
    
    @Override
    public void paintSplitPaneDividerForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintForeground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSplitPaneDragDivider(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSplitPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintSplitPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        if (n5 == 2) {
            AffineTransform affineTransform3 = new AffineTransform();
            affineTransform3.scale(-1.0, 1.0);
            affineTransform3.rotate(Math.toRadians(90.0));
            this.paintBackground(synthContext, graphics, n2, n, n4, n3, affineTransform3);
        }
        else if (n5 == 4) {
            AffineTransform affineTransform2 = new AffineTransform();
            affineTransform2.rotate(Math.toRadians(90.0));
            affineTransform2.translate(0.0, (double)(-(n + n3)));
            this.paintBackground(synthContext, graphics, n2, 0, n4, n3, affineTransform2);
        }
        else if (n5 == 3) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(1.0, -1.0);
            affineTransform.translate(0.0, (double)(-n4));
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
        else {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
    }
    
    @Override
    public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
        if (n6 == 2) {
            AffineTransform affineTransform3 = new AffineTransform();
            affineTransform3.scale(-1.0, 1.0);
            affineTransform3.rotate(Math.toRadians(90.0));
            this.paintBackground(synthContext, graphics, n2, n, n4, n3, affineTransform3);
        }
        else if (n6 == 4) {
            AffineTransform affineTransform2 = new AffineTransform();
            affineTransform2.rotate(Math.toRadians(90.0));
            affineTransform2.translate(0.0, (double)(-(n + n3)));
            this.paintBackground(synthContext, graphics, n2, 0, n4, n3, affineTransform2);
        }
        else if (n6 == 3) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(1.0, -1.0);
            affineTransform.translate(0.0, (double)(-n4));
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
        else {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
    }
    
    @Override
    public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTabbedPaneContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTableHeaderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTableHeaderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTableBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTableBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTextAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTextAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTextPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTextPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBackground(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        if (synthContext.getComponent().getComponentOrientation().isLeftToRight()) {
            this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
        }
        else {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate((double)n, (double)n2);
            affineTransform.scale(-1.0, 1.0);
            affineTransform.translate((double)(-n3), 0.0);
            this.paintBorder(synthContext, graphics, 0, 0, n3, n4, affineTransform);
        }
    }
    
    @Override
    public void paintToggleButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToggleButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, n5);
    }
    
    @Override
    public void paintToolTipBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintToolTipBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTreeBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTreeBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTreeCellBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTreeCellBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintTreeCellFocus(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
    }
    
    @Override
    public void paintViewportBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBackground(synthContext, graphics, n, n2, n3, n4, null);
    }
    
    @Override
    public void paintViewportBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paintBorder(synthContext, graphics, n, n2, n3, n4, null);
    }
}
